@@ -24,6 +24,7 @@ package org.opennms.netmgt.dao;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 
+import org.junit.Assert;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.opennms.core.criteria.CriteriaBuilder;
@@ -51,6 +52,8 @@ import org.springframework.transaction.annotation.Transactional;
 
 import com.google.common.collect.Lists;
 
+import java.time.Duration;
+import java.time.Instant;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
@@ -95,6 +98,86 @@ public class EventDaoIT implements InitializingBean {
         BeanUtils.assertAutowiring(this);
     }
 
+    private OnmsEvent createEvent() {
+
+        OnmsEvent event = new OnmsEvent();
+        event.setEventLog("Y");
+        event.setEventDisplay("Y");
+        event.setEventCreateTime(new Date());
+        event.setDistPoller(m_distPollerDao.whoami());
+        event.setEventTime(new Date());
+        event.setEventSeverity(OnmsSeverity.MAJOR.getId());
+        event.setEventUei("uei://org/opennms/test/EventDaoTest");
+        event.setEventSource("test");
+
+        return event;
+    }
+
+    @Test
+    @Transactional
+    public void testGetNumEventsLastHours() {
+
+        //there exists one populated event in setup with time: 2015-07-14 13:45:48
+        assertEquals(1, m_eventDao.findAll().size());
+
+        //verify 0 count for last 0 hour
+        long eventCount = m_eventDao.getNumEventsLastHours(0);
+        assertEquals(0, eventCount);
+
+        //saving a new event
+        OnmsEvent event = createEvent();
+        m_eventDao.save(event);
+
+        //saving another event
+        OnmsEvent event1 = createEvent();
+        m_eventDao.save(event1);
+
+        //verify all count should be 3 after saving two new events
+        assertEquals(3, m_eventDao.findAll().size());
+
+        //verify zero count for -1 hours,
+        eventCount = m_eventDao.getNumEventsLastHours(-1);
+        assertEquals(0, eventCount);
+        //verify count should be 0 for last 0 hours as per condition
+        eventCount = m_eventDao.getNumEventsLastHours(0);
+        assertEquals(0, eventCount);
+
+        //verify there should be 2 count for last one hour after saving new events
+        eventCount = m_eventDao.getNumEventsLastHours(1);
+        assertEquals(2, eventCount);
+
+        //updating event time 61 minutes earlier
+        event.setEventTime(Date.from(Instant.now().minus(Duration.ofMinutes(61))));
+        m_eventDao.save(event);
+        m_eventDao.flush();
+
+        //verify all count should still be 3 after updating event time
+        assertEquals(3, m_eventDao.findAll().size());
+
+        //verify there should be 1 count after updating event time, event1 event time is same
+        eventCount = m_eventDao.getNumEventsLastHours(1);
+        assertEquals(1, eventCount);
+
+        //verify there should be 2 count for last 10 hours also
+        eventCount = m_eventDao.getNumEventsLastHours(10);
+        assertEquals(2, eventCount);
+
+        //saving another event
+        OnmsEvent event2 = createEvent();
+        event2.setEventTime(Date.from(Instant.now().minus(Duration.ofHours(11))));
+        m_eventDao.save(event2);
+
+        //verify all count should be 4 after adding new with event2 time 11 hours earlier
+        assertEquals(4, m_eventDao.findAll().size());
+        //verify count should be 2 for last 10 hours, as event2 time lies in last 11th hour
+        eventCount = m_eventDao.getNumEventsLastHours(10);
+        assertEquals(2, eventCount);
+
+        //verify count should be 3 for last 11 hours, including 2 events for last 10 hours
+        eventCount = m_eventDao.getNumEventsLastHours(11);
+        assertEquals(3, eventCount);
+    }
+
 	@Test
 	@Transactional
     public void testSave() {
